#Import the basics
from pytriqs.archive import *
from pytriqs.gf.local import *
from pytriqs.operators.util.hamiltonians import *
from pytriqs.operators.util.U_matrix import *

#Import the DFT classes
from pytriqs.applications.dft.sumk_dft import *

#Import the Solver class
from pytriqs.applications.impurity_solvers.cthyb import *

filename = 'NiO'

# Now initialize the DFT class
SK = SumkDFT(hdf_file = filename+'.h5',use_dft_blocks = True)

# Setup the basic structure of the CTQMC Solver
beta = 40.0
n_orb = SK.corr_shells[0]['dim']
spin_names = ['up','down']
orb_names = [i for i in range(0,n_orb)]
gf_struct = SK.gf_struct_solver[0]

#Initialize the Solver class:
S = Solver(beta=beta, gf_struct=gf_struct)

# Now before doing anything, let's check the input Gloc:
SK.put_Sigma([S.Sigma_iw])
Gloc = SK.extract_G_loc()[0]

# Save to files
if mpi.is_master_node():
    A = HDFArchive('NiO.h5','a')
    A['Gloc'] = Gloc
    del A	

    for name, s in Gloc:
    	mesh = np.array([p for p in s.mesh]).reshape(-1,1).imag
    	re_data = s.data.real.reshape((s.data.shape[0],-1))
	im_data = s.data.imag.reshape((s.data.shape[0],-1))

        mesh_a_data = np.hstack((mesh,re_data,im_data))
        np.savetxt('GDFT_' + name + '.dat', mesh_a_data)


