#Import the basics
from pytriqs.archive import *
from pytriqs.gf.local import *
from pytriqs.operators.util.hamiltonians import *
from pytriqs.operators.util.U_matrix import *

#Import the DFT classes
from pytriqs.applications.dft.sumk_dft import *

#Import the Solver class
from pytriqs.applications.impurity_solvers.cthyb import *

filename = 'NiO'

# Now initialize the DFT class
SK = SumkDFT(hdf_file = filename+'.h5',use_dft_blocks = True)

# Setup the basic structure of the CTQMC Solver
beta = 40.0
n_orb = SK.corr_shells[0]['dim']
spin_names = ['up','down']
orb_names = [i for i in range(0,n_orb)]
gf_struct = SK.gf_struct_solver[0]

#Initialize the Solver class:
S = Solver(beta=beta, gf_struct=gf_struct)

# Setup the Hamiltonian
U = 4.0
J = 0.9
U4ind = U_matrix(l=2,U_int=U, J_hund=J, basis = 'cubic')
Umat_eg = eg_submatrix(U = U4ind)

H = h_int_slater(spin_names, orb_names, Umat_eg, off_diag = False)

# Parameters for the CTQMC Solver
p = {}
p["max_time"] = -1
p["random_name"] = ""
p["random_seed"] = 123 * mpi.rank + 567
p["length_cycle"] = 200
p["n_warmup_cycles"] = 1000
p["n_cycles"] = 20000

p["h_int"] = H

# Now prepare the input for the Solver:
SK.put_Sigma(Sigma_imp = [S.Sigma_iw])
SK.calc_mu()
S.G_iw << SK.extract_G_loc()[0]
# Get G0
S.G0_iw << inverse(S.Sigma_iw + inverse(S.G_iw))

# Solve the impurity problem
S.solve(**p)

mpi.report("Impurity density : %s"%S.G_iw.total_density())

# Save to files
if mpi.is_master_node():

    for name, s in S.Sigma_iw:
        mesh = np.array([p for p in s.mesh]).reshape(-1,1).imag
        re_data = s.data.real.reshape((s.data.shape[0],-1))
        im_data = s.data.imag.reshape((s.data.shape[0],-1))

        mesh_a_data = np.hstack((mesh,re_data,im_data))
        np.savetxt('Sigma_ex5_' + name + '.dat', mesh_a_data)


    for name, s in S.G_iw:
        mesh = np.array([p for p in s.mesh]).reshape(-1,1).imag
        re_data = s.data.real.reshape((s.data.shape[0],-1))
        im_data = s.data.imag.reshape((s.data.shape[0],-1))

        mesh_a_data = np.hstack((mesh,re_data,im_data))
        np.savetxt('G_ex5_' + name + '.dat', mesh_a_data)

